@@ -13,8 +13,8 @@
 #:# 
 #:#  Contact us for information about our services: info@rpact.com
 #:# 
-#:#  File version: $Revision: 3585 $
-#:#  Last changed: $Date: 2020-09-03 15:27:08 +0200 (Do, 03 Sep 2020) $
+#:#  File version: $Revision: 3821 $
+#:#  Last changed: $Date: 2020-11-03 08:59:30 +0100 (Tue, 03 Nov 2020) $
 #:#  Last changed by: $Author: pahlke $
 #:# 
 
@@ -1678,7 +1678,8 @@ TrialDesignPlanSurvival <- setRefClass("TrialDesignPlanSurvival",
 	} else {
 		if (designPlan$.piecewiseSurvivalTime$.isLambdaBased(minNumberOfLambdas = 1)) {
 			if (length(designPlan$lambda1) > 1) {
-				warning("Only the first 'lambda1' (", round(designPlan$lambda1[1], 4), 
+				lambda1 <- designPlan$lambda1[1]
+				warning("Only the first 'lambda1' (", round(lambda1, 4), 
 					") was used for plotting", call. = FALSE)
 			}
 		} else {
@@ -1920,9 +1921,17 @@ plot.TrialDesignPlan = function(x, y, ..., main = NA_character_,
 		}
 	}
 	if (length(typeNumbers) == 1) {
+		if (.isSpecialPlotShowSourceArgument(showSource)) {
+			return(invisible(p))
+		}
+		
 		return(p)
 	} 
 	
+	if (.isSpecialPlotShowSourceArgument(showSource)) {
+		return(invisible(plotList))
+	}
+	
 	return(.createPlotResultObject(plotList, grid))
 }
 
